@@ -1,4 +1,3 @@
-
 from jupyter_packaging.__main__ import main
 
 
@@ -6,4 +5,4 @@ def test_main_copies_setupbase(tmpdir):
     d = tmpdir.mkdir("sub")
 
     main([str(d)])
-    assert d.join('setupbase.py').check()
+    assert d.join("setupbase.py").check()
